**Example 1: 释放弹性公网IP**

无

Input: 

```
tccli vpc ReleaseAddresses --cli-unfold-argument  \
    --AddressIds eip-gzc5rgr2
```

Output: 
```
{
    "Response": {
        "TaskId": "12331420",
        "RequestId": "6EF60BEC-0242-43AF-BB20-270359FB54A7"
    }
}
```

